# Pandas Dataframe Algorithms

!!! tip inline end "Pandas Dataframes"
    Pandas dataframes are obviously not going to scale as well as our Spark and SQL Algorithms, but for 'moderate' sized data these algorithms provide some nice functionality.

**Pandas Dataframe Algorithms**

Workbench has a growing set of algorithms and data processing tools for Pandas Dataframes. In general these algorithm will take a dataframe as input and give you back a dataframe with additional columns.

::: workbench.algorithms.dataframe.feature_space_proximity
    options:
      show_root_heading: false
      
::: workbench.algorithms.dataframe.fingerprint_proximity
    options:
      show_root_heading: false

::: workbench.algorithms.dataframe.projection_2d
    options:
      show_root_heading: false

## Questions?
<img align="right" src="../../../images/scp.png" width="180">

The SuperCowPowers team is happy to answer any questions you may have about AWS and Workbench. Please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 


